library("testthat")
library("solaR2")
library("data.table")
setDTthreads(2)

test_check("solaR2")
